DeepAudio-X
===========

DeepAudio-X is a self-supervised audio toolkit for audio classification and related
tasks.

This documentation helps you get started with DeepAudio-X. The :doc:`About <about>`
page provides an overview of the project, :doc:`Installation <installation>`
explains how to set it up, and the :doc:`API Reference <api-reference>` documents
the public Python interface. For more details and updates, see the
`DeepAudio-X GitHub repository <https://github.com/magcil/deepaudio-x>`_.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   about
   installation
   api-reference
